pyxmpp2.binding.ResourceBindingPayload

Package pyxmpp2 :: Module binding :: Class ResourceBindingPayload |
[hide private]

# Class ResourceBindingPayload

Resource binding <iq/> stanza payload.

Nested Classes | [hide private]
Inherited from `interfaces.StanzaPayload`: `__metaclass__`

Instance Methods | [hide private]
__init__(self, element=None, jid=None, resource=None) x.__init__(...) initializes x; see help(type(x)) for signature |
`ElementTree.Element` |
as_xml(self) Return the XML representation of the payload. |
Inherited from `interfaces.StanzaPayload`: `copy` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| _pyxmpp_payload_element_name = ``[``u'``{urn:ietf:params:xml:ns:xmpp``...``
Inherited from `interfaces.StanzaPayload`: `__abstractmethods__` Inherited from `interfaces.StanzaPayload` (private): `_abc_cache`, `_abc_negative_cache`, `_abc_negative_cache_version`, `_abc_registry`

Instance Variables | [hide private]
JID | jid content of the <jid/> child element
`unicode` | resource content of the <resource/> child element

Properties | [hide private]
Inherited from `interfaces.StanzaPayload`: `handler_key` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, element=None, jid=None, resource=None) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### as_xml(self) |
Return the XML representation of the payload. Returns: `ElementTree.Element` Overrides: interfaces.StanzaPayload.as_xml (inherited documentation)

Class Variable Details | [hide private]

  ### _pyxmpp_payload_element_name Value:
      [u'{urn:ietf:params:xml:ns:xmpp-bind}bind']